@@ -263,3 +263,12 @@ impl Serialer for TimeSerialer {
 
 #[cfg(feature = "ticket")]
 pub mod ticket;
+
+#[cfg(feature = "uuid")]
+pub mod uuid;
+
+#[cfg(feature = "auto_increment")]
+pub mod auto_increment;
+
+#[cfg(feature = "random62")]
+pub mod random62;
